=====================
iati software library
=====================

Version **0.0.1dev**

This package acts as a placeholder for the forthcoming :code:`iati.*` python software libraries.

Please see `IATI Discuss <http://discuss.iatistandard.org/c/consultations>`_ for further information on our plans.
